// This file is auto-generated by @hey-api/openapi-ts

import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import type { Observable } from 'rxjs';
import { OpenAPI } from './core/OpenAPI';
import { request as __request } from './core/request';
import type { UpdateQualificationData, UpdateQualificationResponse, DeleteQualificationByDesignationData, DeleteQualificationByDesignationResponse, FindAllResponse, CreateQualificationData, CreateQualificationResponse, FindAllEmployeesByQualificationData, FindAllEmployeesByQualificationResponse, FindByIdData, FindByIdResponse, UpdateEmployeeData, UpdateEmployeeResponse, DeleteCustomerData, DeleteCustomerResponse, PatchEmployeeData, PatchEmployeeResponse, FindAll1Response, CreateEmployeeData, CreateEmployeeResponse, FindAllQualificationOfAemployeeByIdData, FindAllQualificationOfAemployeeByIdResponse, AddQualificationToEmployeeByIdData, AddQualificationToEmployeeByIdResponse, RemoveQualificationFromEmployeeData, RemoveQualificationFromEmployeeResponse } from './types.gen';

@Injectable({
    providedIn: 'root'
})
export class QualificationControllerService {
    constructor(public readonly http: HttpClient) { }
    
    /**
     * updates a qualification
     * @param data The data for the request.
     * @param data.id
     * @param data.requestBody
     * @returns QualificationPostDTO updated qualification
     * @throws ApiError
     */
    public updateQualification(data: UpdateQualificationData): Observable<UpdateQualificationResponse> {
        return __request(OpenAPI, this.http, {
            method: 'PUT',
            url: '/qualifications/{id}',
            path: {
                id: data.id
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted',
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * deletes a qualification by id
     * @param data The data for the request.
     * @param data.id
     * @returns void delete successful
     * @throws ApiError
     */
    public deleteQualificationByDesignation(data: DeleteQualificationByDesignationData): Observable<DeleteQualificationByDesignationResponse> {
        return __request(OpenAPI, this.http, {
            method: 'DELETE',
            url: '/qualifications/{id}',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                403: 'qualification is in use',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * delivers a list of all available qualifications
     * @returns QualificationGetDTO list of qualifications
     * @throws ApiError
     */
    public findAll(): Observable<FindAllResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/qualifications',
            errors: {
                401: 'not authorized'
            }
        });
    }
    
    /**
     * creates a new qualification with its id and designation
     * @param data The data for the request.
     * @param data.requestBody
     * @returns QualificationPostDTO created qualification
     * @throws ApiError
     */
    public createQualification(data: CreateQualificationData): Observable<CreateQualificationResponse> {
        return __request(OpenAPI, this.http, {
            method: 'POST',
            url: '/qualifications',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted',
                401: 'not authorized'
            }
        });
    }
    
    /**
     * find employees by qualification id
     * @param data The data for the request.
     * @param data.id
     * @returns EmployeesForAQualificationDTO List of employees who have the desired qualification
     * @throws ApiError
     */
    public findAllEmployeesByQualification(data: FindAllEmployeesByQualificationData): Observable<FindAllEmployeesByQualificationResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/qualifications/{id}/employees',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'qualification id does not exist'
            }
        });
    }
    
}

@Injectable({
    providedIn: 'root'
})
export class EmployeeControllerService {
    constructor(public readonly http: HttpClient) { }
    
    /**
     * find employee by id
     * @param data The data for the request.
     * @param data.id
     * @returns EmployeeResponseDTO employee
     * @throws ApiError
     */
    public findById(data: FindByIdData): Observable<FindByIdResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/employees/{id}',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * updates employee by id
     * @param data The data for the request.
     * @param data.id
     * @param data.requestBody
     * @returns EmployeeResponseDTO employee
     * @throws ApiError
     */
    public updateEmployee(data: UpdateEmployeeData): Observable<UpdateEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'PUT',
            url: '/employees/{id}',
            path: {
                id: data.id
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * deletes a employee by id
     * @param data The data for the request.
     * @param data.id
     * @returns void delete successful
     * @throws ApiError
     */
    public deleteCustomer(data: DeleteCustomerData): Observable<DeleteCustomerResponse> {
        return __request(OpenAPI, this.http, {
            method: 'DELETE',
            url: '/employees/{id}',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * updates employee by id
     * @param data The data for the request.
     * @param data.id
     * @param data.requestBody
     * @returns EmployeeResponseDTO employee
     * @throws ApiError
     */
    public patchEmployee(data: PatchEmployeeData): Observable<PatchEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'PATCH',
            url: '/employees/{id}',
            path: {
                id: data.id
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * delivers a list of all employees
     * @returns EmployeeResponseDTO list of employees
     * @throws ApiError
     */
    public findAll1(): Observable<FindAll1Response> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/employees',
            errors: {
                401: 'not authorized'
            }
        });
    }
    
    /**
     * creates a new employee
     * @param data The data for the request.
     * @param data.requestBody
     * @returns EmployeeResponseDTO created employee
     * @throws ApiError
     */
    public createEmployee(data: CreateEmployeeData): Observable<CreateEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'POST',
            url: '/employees',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted',
                401: 'not authorized'
            }
        });
    }
    
    /**
     * finds all qualifications of an employee by id
     * @param data The data for the request.
     * @param data.id
     * @returns EmployeeNameAndSkillDataDTO employee with a list of his qualifications
     * @throws ApiError
     */
    public findAllQualificationOfAemployeeById(data: FindAllQualificationOfAemployeeByIdData): Observable<FindAllQualificationOfAemployeeByIdResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/employees/{id}/qualifications',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * adds a qualification to an employee by id
     * @param data The data for the request.
     * @param data.id
     * @param data.requestBody
     * @returns EmployeeNameAndSkillDataDTO employee with a list of his qualifications
     * @throws ApiError
     */
    public addQualificationToEmployeeById(data: AddQualificationToEmployeeByIdData): Observable<AddQualificationToEmployeeByIdResponse> {
        return __request(OpenAPI, this.http, {
            method: 'POST',
            url: '/employees/{id}/qualifications',
            path: {
                id: data.id
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted or employee already has this qualification',
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * deletes a qualification of an employee by id
     * @param data The data for the request.
     * @param data.eid
     * @param data.qid
     * @returns EmployeeNameAndSkillDataDTO employee with a list of his qualifications
     * @throws ApiError
     */
    public removeQualificationFromEmployee(data: RemoveQualificationFromEmployeeData): Observable<RemoveQualificationFromEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'DELETE',
            url: '/employees/{eid}/qualifications/{qid}',
            path: {
                eid: data.eid,
                qid: data.qid
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
}